@@ -27,6 +27,9 @@
 #include "gth-search-task.h"
 
 
+G_DEFINE_TYPE (GthSearchTask, gth_search_task, GTH_TYPE_TASK)
+
+
 struct _GthSearchTaskPrivate
 {
 	GthBrowser    *browser;
@@ -43,9 +46,6 @@ struct _GthSearchTaskPrivate
 };
 
 
-static gpointer parent_class = NULL;
-
-
 static void
 browser_unref_cb (gpointer  data,
 		  GObject  *browser)
@@ -55,7 +55,7 @@ browser_unref_cb (gpointer  data,
 
 
 static void
-gth_task_finalize (GObject *object)
+gth_search_task_finalize (GObject *object)
 {
 	GthSearchTask *task;
 
@@ -72,7 +72,7 @@ gth_task_finalize (GObject *object)
 		task->priv = NULL;
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_search_task_parent_class)->finalize (object);
 }
 
 
@@ -253,6 +253,7 @@ browser_location_ready_cb (GthBrowser    *browser,
 {
 	GtkWidget          *button;
 	EmbeddedDialogData *dialog_data;
+	GSettings          *settings;
 	GString            *attributes;
 	const char         *test_attributes;
 
@@ -310,13 +311,15 @@ browser_location_ready_cb (GthBrowser    *browser,
 		g_object_unref (general_filter);
 	}
 
-	task->priv->show_hidden_files = eel_gconf_get_boolean (PREF_SHOW_HIDDEN_FILES, FALSE);
+	settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
+
+	task->priv->show_hidden_files = g_settings_get_boolean (settings, PREF_BROWSER_SHOW_HIDDEN_FILES);
 	task->priv->io_operation = TRUE;
 
 	task->priv->file_source = gth_main_get_file_source (gth_search_get_folder (task->priv->search));
 	gth_file_source_set_cancellable (task->priv->file_source, gth_task_get_cancellable (GTH_TASK (task)));
 
-	attributes = g_string_new (eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE) ? GFILE_STANDARD_ATTRIBUTES_WITH_FAST_CONTENT_TYPE : GFILE_STANDARD_ATTRIBUTES_WITH_CONTENT_TYPE);
+	attributes = g_string_new (g_settings_get_boolean (settings, PREF_BROWSER_FAST_FILE_TYPE) ? GFILE_STANDARD_ATTRIBUTES_WITH_FAST_CONTENT_TYPE : GFILE_STANDARD_ATTRIBUTES_WITH_CONTENT_TYPE);
 	test_attributes = gth_test_get_attributes (GTH_TEST (task->priv->test));
 	if (test_attributes[0] != '\0') {
 		g_string_append (attributes, ",");
@@ -332,6 +335,7 @@ browser_location_ready_cb (GthBrowser    *browser,
 					done_func,
 					task);
 
+	g_object_unref (settings);
 	g_string_free (attributes, TRUE);
 }
 
@@ -419,10 +423,8 @@ gth_search_task_class_init (GthSearchTaskClass *class)
 	GObjectClass *object_class;
 	GthTaskClass *task_class;
 
-	parent_class = g_type_class_peek_parent (class);
-
 	object_class = (GObjectClass*) class;
-	object_class->finalize = gth_task_finalize;
+	object_class->finalize = gth_search_task_finalize;
 
 	task_class = (GthTaskClass*) class;
 	task_class->exec = gth_search_task_exec;
@@ -437,34 +439,6 @@ gth_search_task_init (GthSearchTask *task)
 }
 
 
-GType
-gth_search_task_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthSearchTaskClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_search_task_class_init,
-			NULL,
-			NULL,
-			sizeof (GthSearchTask),
-			0,
-			(GInstanceInitFunc) gth_search_task_init
-		};
-
-		type = g_type_register_static (GTH_TYPE_TASK,
-					       "GthSearchTask",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthTask *
 gth_search_task_new (GthBrowser *browser,
 		     GthSearch  *search,
