@@ -38,6 +38,9 @@
 #define DEFAULT_DELAY 2000
 
 
+G_DEFINE_TYPE (GthSlideshow, gth_slideshow, GTK_TYPE_WINDOW)
+
+
 typedef enum {
 	GTH_SLIDESHOW_DIRECTION_FORWARD,
 	GTH_SLIDESHOW_DIRECTION_BACKWARD
@@ -88,9 +91,6 @@ struct _GthSlideshowPrivate {
 };
 
 
-static gpointer parent_class = NULL;
-
-
 static void
 _gth_slideshow_close (GthSlideshow *self)
 {
@@ -268,35 +268,6 @@ image_preloader_requested_ready_cb (GthImagePreloader  *preloader,
 }
 
 
-static void
-gth_slideshow_init (GthSlideshow *self)
-{
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_SLIDESHOW, GthSlideshowPrivate);
-	self->priv->file_list = NULL;
-	self->priv->next_event = 0;
-	self->priv->delay = DEFAULT_DELAY;
-	self->priv->automatic = FALSE;
-	self->priv->wrap_around = FALSE;
-	self->priv->transitions = NULL;
-	self->priv->n_transitions = 0;
-	self->priv->rand = g_rand_new ();
-	self->priv->first_show = TRUE;
-	self->priv->audio_files = NULL;
-	self->priv->paused = FALSE;
-	self->priv->animating = FALSE;
-	self->priv->direction = GTH_SLIDESHOW_DIRECTION_FORWARD;
-	self->priv->random_order = FALSE;
-	self->priv->current_pixbuf = NULL;
-	self->priv->screensaver = gth_screensaver_new (NULL);
-
-	self->priv->preloader = gth_image_preloader_new (GTH_LOAD_POLICY_ONE_STEP, 3);
-	g_signal_connect (self->priv->preloader,
-			  "requested_ready",
-			  G_CALLBACK (image_preloader_requested_ready_cb),
-			  self);
-}
-
-
 static void
 gth_slideshow_finalize (GObject *object)
 {
@@ -329,7 +300,7 @@ gth_slideshow_finalize (GObject *object)
 		g_object_unref (self->priv->screensaver);
 	}
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_slideshow_parent_class)->finalize (object);
 }
 
 
@@ -338,7 +309,6 @@ gth_slideshow_class_init (GthSlideshowClass *klass)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthSlideshowPrivate));
 
 	gobject_class = G_OBJECT_CLASS (klass);
@@ -346,34 +316,6 @@ gth_slideshow_class_init (GthSlideshowClass *klass)
 }
 
 
-GType
-gth_slideshow_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthSlideshowClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_slideshow_class_init,
-			NULL,
-			NULL,
-			sizeof (GthSlideshow),
-			0,
-			(GInstanceInitFunc) gth_slideshow_init
-		};
-
-		type = g_type_register_static (GTK_TYPE_WINDOW,
-					       "GthSlideshow",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 static gboolean
 hide_cursor_cb (gpointer data)
 {
@@ -466,6 +408,35 @@ gth_slideshow_show_cb (GtkWidget    *widget,
 }
 
 
+static void
+gth_slideshow_init (GthSlideshow *self)
+{
+	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GTH_TYPE_SLIDESHOW, GthSlideshowPrivate);
+	self->priv->file_list = NULL;
+	self->priv->next_event = 0;
+	self->priv->delay = DEFAULT_DELAY;
+	self->priv->automatic = FALSE;
+	self->priv->wrap_around = FALSE;
+	self->priv->transitions = NULL;
+	self->priv->n_transitions = 0;
+	self->priv->rand = g_rand_new ();
+	self->priv->first_show = TRUE;
+	self->priv->audio_files = NULL;
+	self->priv->paused = FALSE;
+	self->priv->animating = FALSE;
+	self->priv->direction = GTH_SLIDESHOW_DIRECTION_FORWARD;
+	self->priv->random_order = FALSE;
+	self->priv->current_pixbuf = NULL;
+	self->priv->screensaver = gth_screensaver_new (NULL);
+
+	self->priv->preloader = gth_image_preloader_new (GTH_LOAD_POLICY_ONE_STEP, 3);
+	g_signal_connect (self->priv->preloader,
+			  "requested_ready",
+			  G_CALLBACK (image_preloader_requested_ready_cb),
+			  self);
+}
+
+
 static void
 _gth_slideshow_construct (GthSlideshow *self,
 			  GthProjector *projector,
@@ -641,35 +612,35 @@ viewer_event_cb (GtkWidget    *widget,
 	}
 	else if (event->type == GDK_KEY_PRESS) {
 		switch (((GdkEventKey *) event)->keyval) {
-		case GDK_F5:
+		case GDK_KEY_F5:
 			_gth_slideshow_close (self);
 			break;
 		}
 	}
 	else if (event->type == GDK_KEY_RELEASE) {
 		switch (((GdkEventKey *) event)->keyval) {
-		case GDK_Escape:
-		case GDK_q:
+		case GDK_KEY_Escape:
+		case GDK_KEY_q:
 			_gth_slideshow_close (self);
 			break;
-		case GDK_p:
+		case GDK_KEY_p:
 			_gth_slideshow_toggle_pause (self);
 			break;
 
-		case GDK_space:
-		case GDK_Down:
-		case GDK_Right:
-		case GDK_Page_Down:
+		case GDK_KEY_space:
+		case GDK_KEY_Down:
+		case GDK_KEY_Right:
+		case GDK_KEY_Page_Down:
 			if (self->priv->paused)
 				_gth_slideshow_toggle_pause (self);
 			else
 				_gth_slideshow_load_next_image (self);
 			break;
 
-		case GDK_BackSpace:
-		case GDK_Up:
-		case GDK_Left:
-		case GDK_Page_Up:
+		case GDK_KEY_BackSpace:
+		case GDK_KEY_Up:
+		case GDK_KEY_Left:
+		case GDK_KEY_Page_Up:
 			_gth_slideshow_load_prev_image (self);
 			break;
 		}
@@ -694,7 +665,6 @@ hide_paused_sign_cb (gpointer user_data)
 
 static void
 default_projector_pause_painter (GthImageViewer *image_viewer,
-				 GdkEventExpose *event,
 				 cairo_t        *cr,
 				 gpointer        user_data)
 {
@@ -964,7 +934,7 @@ clutter_projector_image_ready (GthSlideshow *self,
 		texture = self->priv->image1;
 	else
 		texture = self->priv->image2;
-	gtk_clutter_texture_set_from_pixbuf (CLUTTER_TEXTURE (texture), image, NULL);
+	gtk_clutter_texture_set_from_pixbuf (GTK_CLUTTER_TEXTURE (texture), image, NULL);
 
 	self->next_geometry.x = 0;
 	self->next_geometry.y = 0;
@@ -1147,7 +1117,7 @@ adapt_image_size_to_stage_size (GthSlideshow *self)
 		texture = self->priv->image1;
 	else
 		texture = self->priv->image2;
-	gtk_clutter_texture_set_from_pixbuf (CLUTTER_TEXTURE (texture), image, NULL);
+	gtk_clutter_texture_set_from_pixbuf (GTK_CLUTTER_TEXTURE (texture), image, NULL);
 
 	self->current_geometry.x = 0;
 	self->current_geometry.y = 0;
@@ -1185,11 +1155,11 @@ clutter_projector_construct (GthSlideshow *self)
 	g_signal_connect (self->stage, "key-press-event", G_CALLBACK (stage_input_cb), self);
 	g_signal_connect (self->stage, "key-release-event", G_CALLBACK (stage_input_cb), self);
 
-	self->priv->image1 = clutter_texture_new ();
+	self->priv->image1 = gtk_clutter_texture_new ();
 	clutter_actor_hide (self->priv->image1);
 	clutter_container_add_actor (CLUTTER_CONTAINER (self->stage), self->priv->image1);
 
-	self->priv->image2 = clutter_texture_new ();
+	self->priv->image2 = gtk_clutter_texture_new ();
 	clutter_actor_hide (self->priv->image2);
 	clutter_container_add_actor (CLUTTER_CONTAINER (self->stage), self->priv->image2);
 
@@ -1203,12 +1173,17 @@ clutter_projector_construct (GthSlideshow *self)
 
 	self->priv->alpha = clutter_alpha_new_full (self->priv->timeline, CLUTTER_EASE_IN_OUT_SINE);
 
+	self->priv->paused_actor = gtk_clutter_texture_new ();
 	if (self->priv->pause_pixbuf != NULL)
-		self->priv->paused_actor = gtk_clutter_texture_new_from_pixbuf (self->priv->pause_pixbuf);
+		gtk_clutter_texture_set_from_pixbuf (GTK_CLUTTER_TEXTURE (self->priv->paused_actor),
+				 	 	     self->priv->pause_pixbuf,
+				 	 	     NULL);
 	else
-		self->priv->paused_actor = gtk_clutter_texture_new_from_stock (GTK_WIDGET (self),
-									       GTK_STOCK_MEDIA_PAUSE,
-									       GTK_ICON_SIZE_DIALOG);
+		gtk_clutter_texture_set_from_stock (GTK_CLUTTER_TEXTURE (self->priv->paused_actor),
+						    GTK_WIDGET (self),
+						    GTK_STOCK_MEDIA_PAUSE,
+						    GTK_ICON_SIZE_DIALOG,
+						    NULL);
 	clutter_actor_hide (self->priv->paused_actor);
 	clutter_container_add_actor (CLUTTER_CONTAINER (self->stage), self->priv->paused_actor);
 
