@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 2.6.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5"
+#define YYBISON_VERSION "2.6.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,8 +58,6 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
 #define yyparse         gth_albumtheme_yyparse
@@ -70,11 +68,9 @@
 #define yydebug         gth_albumtheme_yydebug
 #define yynerrs         gth_albumtheme_yynerrs
 
-
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
-#line 1 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 336 of yacc.c  */
+#line 1 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
 
 /*
  *  GThumb
@@ -110,14 +106,16 @@ int   gth_albumtheme_yywrap  (void);
 #define YYERROR_VERBOSE 1
 
 
+/* Line 336 of yacc.c  */
+#line 111 "albumtheme.c"
 
-/* Line 268 of yacc.c  */
-#line 116 "albumtheme.c"
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+# ifndef YY_NULL
+#  if defined __cplusplus && 201103L <= __cplusplus
+#   define YY_NULL nullptr
+#  else
+#   define YY_NULL 0
+#  endif
+# endif
 
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
@@ -127,11 +125,17 @@ int   gth_albumtheme_yywrap  (void);
 # define YYERROR_VERBOSE 0
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "".  */
+#ifndef GTH_ALBUMTHEME_YY_
+# define GTH_ALBUMTHEME_YY_
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int gth_albumtheme_yydebug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -162,13 +166,11 @@ int   gth_albumtheme_yywrap  (void);
 #endif
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 293 of yacc.c  */
-#line 37 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 350 of yacc.c  */
+#line 37 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
 
 	char         *text;
 	int           ivalue;
@@ -180,21 +182,36 @@ typedef union YYSTYPE
 	GthLoop      *loop;
 
 
-
-/* Line 293 of yacc.c  */
-#line 186 "albumtheme.c"
+/* Line 350 of yacc.c  */
+#line 187 "albumtheme.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+extern YYSTYPE gth_albumtheme_yylval;
+
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int gth_albumtheme_yyparse (void *YYPARSE_PARAM);
+#else
+int gth_albumtheme_yyparse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int gth_albumtheme_yyparse (void);
+#else
+int gth_albumtheme_yyparse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !GTH_ALBUMTHEME_YY_  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 343 of yacc.c  */
-#line 198 "albumtheme.c"
+/* Line 353 of yacc.c  */
+#line 215 "albumtheme.c"
 
 #ifdef short
 # undef short
@@ -300,6 +317,7 @@ YYID (yyi)
 #    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS && (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 #     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
+      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
 #     ifndef EXIT_SUCCESS
 #      define EXIT_SUCCESS 0
 #     endif
@@ -391,20 +409,20 @@ union yyalloc
 #endif
 
 #if defined YYCOPY_NEEDED && YYCOPY_NEEDED
-/* Copy COUNT objects from FROM to TO.  The source and destination do
+/* Copy COUNT objects from SRC to DST.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
 #  if defined __GNUC__ && 1 < __GNUC__
-#   define YYCOPY(To, From, Count) \
-      __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
+#   define YYCOPY(Dst, Src, Count) \
+      __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
 #  else
-#   define YYCOPY(To, From, Count)		\
-      do					\
-	{					\
-	  YYSIZE_T yyi;				\
-	  for (yyi = 0; yyi < (Count); yyi++)	\
-	    (To)[yyi] = (From)[yyi];		\
-	}					\
+#   define YYCOPY(Dst, Src, Count)              \
+      do                                        \
+        {                                       \
+          YYSIZE_T yyi;                         \
+          for (yyi = 0; yyi < (Count); yyi++)   \
+            (Dst)[yyi] = (Src)[yyi];            \
+        }                                       \
       while (YYID (0))
 #  endif
 # endif
@@ -509,7 +527,7 @@ static const yytype_uint16 yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -521,7 +539,7 @@ static const char *const yytname[] =
   "'\"'", "'='", "'\\''", "'('", "')'", "$accept", "all", "document",
   "tag_loop", "tag_if", "opt_tag_else_if", "tag_else_if", "opt_tag_else",
   "tag_else", "tag_end", "tag_command", "tag_print", "attribute_list",
-  "attribute", "expr_list", "expr", 0
+  "attribute", "expr_list", "expr", YY_NULL
 };
 #endif
 
@@ -719,17 +737,18 @@ static const yytype_uint8 yystos[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)					\
-do								\
-  if (yychar == YYEMPTY && yylen == 1)				\
-    {								\
-      yychar = (Token);						\
-      yylval = (Value);						\
-      YYPOPSTACK (1);						\
-      goto yybackup;						\
-    }								\
-  else								\
-    {								\
+#define YYBACKUP(Token, Value)                                  \
+do                                                              \
+  if (yychar == YYEMPTY)                                        \
+    {                                                           \
+      yychar = (Token);                                         \
+      yylval = (Value);                                         \
+      YYPOPSTACK (yylen);                                       \
+      yystate = *yyssp;                                         \
+      goto yybackup;                                            \
+    }                                                           \
+  else                                                          \
+    {                                                           \
       yyerror (YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
@@ -739,32 +758,33 @@ while (YYID (0))
 #define YYTERROR	1
 #define YYERRCODE	256
 
-
 /* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
+
 
 /* This macro is provided for backward compatibility. */
 
@@ -824,6 +844,8 @@ yy_symbol_value_print (yyoutput, yytype, yyvaluep)
     YYSTYPE const * const yyvaluep;
 #endif
 {
+  FILE *yyo = yyoutput;
+  YYUSE (yyo);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -1075,12 +1097,12 @@ static int
 yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yytype_int16 *yyssp, int yytoken)
 {
-  YYSIZE_T yysize0 = yytnamerr (0, yytname[yytoken]);
+  YYSIZE_T yysize0 = yytnamerr (YY_NULL, yytname[yytoken]);
   YYSIZE_T yysize = yysize0;
   YYSIZE_T yysize1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
-  const char *yyformat = 0;
+  const char *yyformat = YY_NULL;
   /* Arguments of yyformat. */
   char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
   /* Number of reported tokens (one for the "unexpected", one per
@@ -1140,7 +1162,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                     break;
                   }
                 yyarg[yycount++] = yytname[yyx];
-                yysize1 = yysize + yytnamerr (0, yytname[yyx]);
+                yysize1 = yysize + yytnamerr (YY_NULL, yytname[yyx]);
                 if (! (yysize <= yysize1
                        && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
                   return 2;
@@ -1232,20 +1254,6 @@ yydestruct (yymsg, yytype, yyvaluep)
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
@@ -1292,7 +1300,7 @@ yyparse ()
        `yyss': related to states.
        `yyvs': related to semantic values.
 
-       Refer to the stacks thru separate pointers, to allow yyoverflow
+       Refer to the stacks through separate pointers, to allow yyoverflow
        to reallocate them elsewhere.  */
 
     /* The state stack.  */
@@ -1346,7 +1354,6 @@ yyparse ()
      The wasted elements are never initialized.  */
   yyssp = yyss;
   yyvsp = yyvs;
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1524,9 +1531,8 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-
-/* Line 1806 of yacc.c  */
-#line 77 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 77 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			yy_parsed_doc = (yyvsp[(1) - (1)].list);
 			if (yy_parsed_doc == NULL)
@@ -1537,9 +1543,8 @@ yyreduce:
     break;
 
   case 3:
-
-/* Line 1806 of yacc.c  */
-#line 86 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 86 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), gth_tag_new_html ((yyvsp[(1) - (2)].text)));
 			g_free ((yyvsp[(1) - (2)].text));
@@ -1547,27 +1552,24 @@ yyreduce:
     break;
 
   case 4:
-
-/* Line 1806 of yacc.c  */
-#line 91 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 91 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		}
     break;
 
   case 5:
-
-/* Line 1806 of yacc.c  */
-#line 95 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 95 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].tag));
 		}
     break;
 
   case 6:
-
-/* Line 1806 of yacc.c  */
-#line 99 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 99 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthTag *tag;
 
@@ -1578,9 +1580,8 @@ yyreduce:
     break;
 
   case 7:
-
-/* Line 1806 of yacc.c  */
-#line 107 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 107 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GList  *cond_list;
 			GthTag *tag;
@@ -1596,18 +1597,16 @@ yyreduce:
     break;
 
   case 8:
-
-/* Line 1806 of yacc.c  */
-#line 120 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 120 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 9:
-
-/* Line 1806 of yacc.c  */
-#line 124 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 124 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			/*if ($2 != NULL)
 				gth_parsed_doc_free ($2);*/
@@ -1616,9 +1615,8 @@ yyreduce:
     break;
 
   case 10:
-
-/* Line 1806 of yacc.c  */
-#line 131 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 131 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			if (g_str_equal ((yyvsp[(2) - (3)].text), "thumbnail_caption")) {
 				(yyval.loop) = gth_loop_new (GTH_TAG_FOR_EACH_THUMBNAIL_CAPTION);
@@ -1634,9 +1632,8 @@ yyreduce:
     break;
 
   case 11:
-
-/* Line 1806 of yacc.c  */
-#line 144 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 144 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.loop) = gth_range_loop_new ();
 			gth_range_loop_set_range (GTH_RANGE_LOOP ((yyval.loop)), (yyvsp[(2) - (7)].text), (yyvsp[(4) - (7)].expr), (yyvsp[(6) - (7)].expr));
@@ -1648,27 +1645,24 @@ yyreduce:
     break;
 
   case 12:
-
-/* Line 1806 of yacc.c  */
-#line 154 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 154 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		}
     break;
 
   case 13:
-
-/* Line 1806 of yacc.c  */
-#line 158 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 158 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		}
     break;
 
   case 14:
-
-/* Line 1806 of yacc.c  */
-#line 163 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 163 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			gth_condition_add_document ((yyvsp[(1) - (3)].cond), (yyvsp[(2) - (3)].list));
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].cond));
@@ -1676,36 +1670,32 @@ yyreduce:
     break;
 
   case 15:
-
-/* Line 1806 of yacc.c  */
-#line 168 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 168 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 16:
-
-/* Line 1806 of yacc.c  */
-#line 173 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 173 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(2) - (3)].expr));
 		}
     break;
 
   case 17:
-
-/* Line 1806 of yacc.c  */
-#line 177 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 177 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = gth_condition_new ((yyvsp[(3) - (5)].expr));
 		}
     break;
 
   case 18:
-
-/* Line 1806 of yacc.c  */
-#line 182 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 182 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr      *else_expr;
 			GthCondition *cond;
@@ -1720,27 +1710,24 @@ yyreduce:
     break;
 
   case 19:
-
-/* Line 1806 of yacc.c  */
-#line 194 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 194 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.cond) = NULL;
 		}
     break;
 
   case 22:
-
-/* Line 1806 of yacc.c  */
-#line 205 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 205 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.tag) = gth_tag_new (GTH_TAG_SET_VAR, (yyvsp[(2) - (3)].list));
 		}
     break;
 
   case 23:
-
-/* Line 1806 of yacc.c  */
-#line 210 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 210 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			if (gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text)) == GTH_TAG_EVAL) {
 				GthExpr *e;
@@ -1791,9 +1778,8 @@ yyreduce:
     break;
 
   case 24:
-
-/* Line 1806 of yacc.c  */
-#line 258 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 258 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthTagType tag_type = gth_tag_get_type_from_name ((yyvsp[(2) - (4)].text));
 			if (tag_type == GTH_TAG_INVALID) {
@@ -1805,27 +1791,24 @@ yyreduce:
     break;
 
   case 25:
-
-/* Line 1806 of yacc.c  */
-#line 268 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 268 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(2) - (2)].list), (yyvsp[(1) - (2)].attribute));
 		}
     break;
 
   case 26:
-
-/* Line 1806 of yacc.c  */
-#line 272 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 272 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 27:
-
-/* Line 1806 of yacc.c  */
-#line 277 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 277 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_expression ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].expr));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1833,9 +1816,8 @@ yyreduce:
     break;
 
   case 28:
-
-/* Line 1806 of yacc.c  */
-#line 282 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 282 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.attribute) = gth_attribute_new_string ((yyvsp[(1) - (5)].text), (yyvsp[(4) - (5)].text));
 			g_free ((yyvsp[(1) - (5)].text));
@@ -1844,9 +1826,8 @@ yyreduce:
     break;
 
   case 29:
-
-/* Line 1806 of yacc.c  */
-#line 288 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 288 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, 1);
@@ -1856,45 +1837,40 @@ yyreduce:
     break;
 
   case 30:
-
-/* Line 1806 of yacc.c  */
-#line 296 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 296 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend ((yyvsp[(3) - (3)].list), (yyvsp[(1) - (3)].expr));
 		}
     break;
 
   case 31:
-
-/* Line 1806 of yacc.c  */
-#line 300 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 300 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = g_list_prepend (NULL, (yyvsp[(1) - (1)].expr));
 		}
     break;
 
   case 32:
-
-/* Line 1806 of yacc.c  */
-#line 304 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 304 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.list) = NULL;
 		}
     break;
 
   case 33:
-
-/* Line 1806 of yacc.c  */
-#line 309 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 309 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (3)].expr);
 		}
     break;
 
   case 34:
-
-/* Line 1806 of yacc.c  */
-#line 313 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 313 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1910,9 +1886,8 @@ yyreduce:
     break;
 
   case 35:
-
-/* Line 1806 of yacc.c  */
-#line 326 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 326 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1928,9 +1903,8 @@ yyreduce:
     break;
 
   case 36:
-
-/* Line 1806 of yacc.c  */
-#line 339 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 339 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1946,9 +1920,8 @@ yyreduce:
     break;
 
   case 37:
-
-/* Line 1806 of yacc.c  */
-#line 352 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 352 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1964,9 +1937,8 @@ yyreduce:
     break;
 
   case 38:
-
-/* Line 1806 of yacc.c  */
-#line 365 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 365 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -1982,9 +1954,8 @@ yyreduce:
     break;
 
   case 39:
-
-/* Line 1806 of yacc.c  */
-#line 378 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 378 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 
@@ -2000,18 +1971,16 @@ yyreduce:
     break;
 
   case 40:
-
-/* Line 1806 of yacc.c  */
-#line 391 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 391 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
 		}
     break;
 
   case 41:
-
-/* Line 1806 of yacc.c  */
-#line 395 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 395 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NEG);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -2019,9 +1988,8 @@ yyreduce:
     break;
 
   case 42:
-
-/* Line 1806 of yacc.c  */
-#line 400 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 400 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			gth_expr_push_op ((yyvsp[(2) - (2)].expr), GTH_OP_NOT);
 			(yyval.expr) = (yyvsp[(2) - (2)].expr);
@@ -2029,9 +1997,8 @@ yyreduce:
     break;
 
   case 43:
-
-/* Line 1806 of yacc.c  */
-#line 405 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 405 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     { /* function call */
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (4)].text));
@@ -2051,9 +2018,8 @@ yyreduce:
     break;
 
   case 44:
-
-/* Line 1806 of yacc.c  */
-#line 422 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 422 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_var (e, (yyvsp[(1) - (1)].text));
@@ -2063,9 +2029,8 @@ yyreduce:
     break;
 
   case 45:
-
-/* Line 1806 of yacc.c  */
-#line 429 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 429 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_string (e, (yyvsp[(2) - (3)].text));
@@ -2075,9 +2040,8 @@ yyreduce:
     break;
 
   case 46:
-
-/* Line 1806 of yacc.c  */
-#line 436 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 1787 of yacc.c  */
+#line 436 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
     {
 			GthExpr *e = gth_expr_new ();
 			gth_expr_push_integer (e, (yyvsp[(1) - (1)].ivalue));
@@ -2086,9 +2050,8 @@ yyreduce:
     break;
 
 
-
-/* Line 1806 of yacc.c  */
-#line 2092 "albumtheme.c"
+/* Line 1787 of yacc.c  */
+#line 2055 "albumtheme.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2275,7 +2238,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#if !defined(yyoverflow) || YYERROR_VERBOSE
+#if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2317,9 +2280,8 @@ yyreturn:
 }
 
 
-
-/* Line 2067 of yacc.c  */
-#line 443 "/home/paolo/workspace/gthumb/extensions/webalbums/albumtheme.y"
+/* Line 2048 of yacc.c  */
+#line 443 "/home/paolo/workspace/gthumb-3-0/extensions/webalbums/albumtheme.y"
 
 
 
@@ -2343,4 +2305,3 @@ gth_albumtheme_yyerror (const char *fmt, ...)
 
 
 #include "albumtheme-lex.c"
-
