@@ -40,17 +40,8 @@
 #define DEFAULT_INDEX_FILE "index.html"
 #define SAVING_TIMEOUT 5
 
-/* Default subdirectories.
- * - Used as fallback when gconf values are empty or not accessible
- * - Please keep in sync with values in gthumb.schemas.in
- */
 
-#define DEFAULT_WEB_DIR_PREVIEWS     "previews"
-#define DEFAULT_WEB_DIR_THUMBNAILS   "thumbnails"
-#define DEFAULT_WEB_DIR_IMAGES       "images"
-#define DEFAULT_WEB_DIR_HTML_IMAGES  "html"
-#define DEFAULT_WEB_DIR_HTML_INDEXES "html"
-#define DEFAULT_WEB_DIR_THEME_FILES  "theme"
+G_DEFINE_TYPE (GthWebExporter, gth_web_exporter, GTH_TYPE_TASK)
 
 
 typedef enum {
@@ -75,7 +66,6 @@ typedef enum {
 
 extern GFileInputStream *yy_istream;
 
-static GObjectClass *parent_class = NULL;
 
 typedef struct {
 	GthFileData *file_data;
@@ -1391,7 +1381,7 @@ gth_parsed_doc_print (GthWebExporter      *self,
 		case GTH_TAG_FILE_SIZE:
 			idx = get_image_idx (tag, self);
 			idata = g_list_nth (self->priv->file_list, idx)->data;
-			line = g_format_size_for_display (g_file_info_get_size (idata->file_data->info));
+			line = g_format_size (g_file_info_get_size (idata->file_data->info));
 			write_markup_escape_line (ostream, line, error);
 			break;
 
@@ -2918,6 +2908,7 @@ gth_web_exporter_exec (GthTask *task)
 {
 	GthWebExporter *self;
 	GError         *error = NULL;
+	GSettings      *settings;
 	GString        *required_attributes;
 
 	g_return_if_fail (GTH_IS_WEB_EXPORTER (task));
@@ -2954,15 +2945,20 @@ gth_web_exporter_exec (GthTask *task)
 	if (self->priv->images_per_index % self->priv->columns_per_page > 0)
 		self->priv->rows_per_page++;
 
-	/* get index file name and subdirs from gconf (hidden prefs) */
+	/* get index file name and sub-directories (hidden preferences) */
 
-	self->priv->index_file = eel_gconf_get_string (PREF_WEBALBUMS_INDEX_FILE, DEFAULT_INDEX_FILE);
-	self->priv->directories.previews = eel_gconf_get_string (PREF_WEBALBUMS_DIR_PREVIEWS, DEFAULT_WEB_DIR_PREVIEWS);
-	self->priv->directories.thumbnails = eel_gconf_get_string (PREF_WEBALBUMS_DIR_THUMBNAILS, DEFAULT_WEB_DIR_THUMBNAILS);
-	self->priv->directories.images = eel_gconf_get_string (PREF_WEBALBUMS_DIR_IMAGES, DEFAULT_WEB_DIR_IMAGES);
-	self->priv->directories.html_images = eel_gconf_get_string (PREF_WEBALBUMS_DIR_HTML_IMAGES, DEFAULT_WEB_DIR_HTML_IMAGES);
-	self->priv->directories.html_indexes = eel_gconf_get_string (PREF_WEBALBUMS_DIR_HTML_INDEXES, DEFAULT_WEB_DIR_HTML_INDEXES);
-	self->priv->directories.theme_files = eel_gconf_get_string (PREF_WEBALBUMS_DIR_THEME_FILES, DEFAULT_WEB_DIR_THEME_FILES);
+	settings = g_settings_new (GTHUMB_WEBALBUMS_SCHEMA);
+	self->priv->index_file = g_settings_get_string (settings, PREF_WEBALBUMS_INDEX_FILE);
+	g_object_unref (settings);
+
+	settings = g_settings_new (GTHUMB_WEBALBUMS_DIRECTORIES_SCHEMA);
+	self->priv->directories.previews = g_settings_get_string (settings, PREF_WEBALBUMS_DIR_PREVIEWS);
+	self->priv->directories.thumbnails = g_settings_get_string (settings, PREF_WEBALBUMS_DIR_THUMBNAILS);
+	self->priv->directories.images = g_settings_get_string (settings, PREF_WEBALBUMS_DIR_IMAGES);
+	self->priv->directories.html_images = g_settings_get_string (settings, PREF_WEBALBUMS_DIR_HTML_IMAGES);
+	self->priv->directories.html_indexes = g_settings_get_string (settings, PREF_WEBALBUMS_DIR_HTML_INDEXES);
+	self->priv->directories.theme_files = g_settings_get_string (settings, PREF_WEBALBUMS_DIR_THEME_FILES);
+	g_object_unref (settings);
 
 	/* create a tmp dir */
 
@@ -3100,7 +3096,7 @@ gth_web_exporter_finalize (GObject *object)
 	}
 	_g_object_list_unref (self->priv->gfile_list);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_web_exporter_parent_class)->finalize (object);
 }
 
 
@@ -3110,7 +3106,6 @@ gth_web_exporter_class_init (GthWebExporterClass *klass)
 	GObjectClass *object_class;
 	GthTaskClass *task_class;
 
-	parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthWebExporterPrivate));
 
 	object_class = G_OBJECT_CLASS (klass);
@@ -3166,34 +3161,6 @@ gth_web_exporter_init (GthWebExporter *self)
 }
 
 
-GType
-gth_web_exporter_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthWebExporterClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_web_exporter_class_init,
-			NULL,
-			NULL,
-			sizeof (GthWebExporter),
-			0,
-			(GInstanceInitFunc) gth_web_exporter_init
-                };
-
-                type = g_type_register_static (GTH_TYPE_TASK,
-					       "GthWebExporter",
-					       &type_info,
-					       0);
-        }
-
-	return type;
-}
-
-
 GthTask *
 gth_web_exporter_new (GthBrowser *browser,
 		      GList      *file_list)
