@@ -53,7 +53,7 @@ struct _GthAsyncTaskPrivate {
 };
 
 
-static gpointer parent_class = NULL;
+G_DEFINE_TYPE (GthAsyncTask, gth_async_task, GTH_TYPE_TASK)
 
 
 static void
@@ -74,7 +74,7 @@ gth_async_task_finalize (GObject *object)
 
 	g_mutex_free (self->priv->data_mutex);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_async_task_parent_class)->finalize (object);
 }
 
 
@@ -250,7 +250,6 @@ gth_async_task_class_init (GthAsyncTaskClass *class)
 	GObjectClass *object_class;
 	GthTaskClass *task_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthAsyncTaskPrivate));
 
 	object_class = G_OBJECT_CLASS (class);
@@ -308,34 +307,6 @@ gth_async_task_init (GthAsyncTask *self)
 }
 
 
-GType
-gth_async_task_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthAsyncTaskClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_async_task_class_init,
-			NULL,
-			NULL,
-			sizeof (GthAsyncTask),
-			0,
-			(GInstanceInitFunc) gth_async_task_init
-		};
-
-		type = g_type_register_static (GTH_TYPE_TASK,
-					       "GthAsyncTask",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthTask *
 gth_async_task_new (GthAsyncInitFunc    before_func,
 		    GthAsyncThreadFunc  exec_func,
