@@ -21,6 +21,7 @@
 
 #include <config.h>
 #include <glib/gi18n.h>
+#include "dlg-location.h"
 #include "dlg-personalize-filters.h"
 #include "dlg-preferences.h"
 #include "dlg-sort-order.h"
@@ -139,6 +140,14 @@ gth_browser_activate_action_go_up (GtkAction  *action,
 }
 
 
+void
+gth_browser_activate_action_go_location (GtkAction  *action,
+					 GthBrowser *browser)
+{
+	dlg_location (browser);
+}
+
+
 void
 gth_browser_activate_action_go_home (GtkAction  *action,
 				     GthBrowser *browser)
