@@ -22,7 +22,6 @@
 #include <config.h>
 #include <math.h>
 #include "glib-utils.h"
-#include "gth-cursors.h"
 #include "gth-image-dragger.h"
 
 
@@ -32,7 +31,14 @@ struct _GthImageDraggerPrivate {
 };
 
 
-static gpointer parent_class = NULL;
+static void gth_image_dragger_gth_image_tool_interface_init (GthImageViewerToolInterface *iface);
+
+
+G_DEFINE_TYPE_WITH_CODE (GthImageDragger,
+			 gth_image_dragger,
+			 G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (GTH_TYPE_IMAGE_VIEWER_TOOL,
+					        gth_image_dragger_gth_image_tool_interface_init))
 
 
 static void
@@ -42,7 +48,7 @@ gth_image_dragger_finalize (GObject *object)
 	g_return_if_fail (GTH_IS_IMAGE_DRAGGER (object));
 
 	/* Chain up */
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_image_dragger_parent_class)->finalize (object);
 }
 
 
@@ -51,7 +57,6 @@ gth_image_dragger_class_init (GthImageDraggerClass *class)
 {
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthImageDraggerPrivate));
 
 	gobject_class = (GObjectClass*) class;
@@ -60,24 +65,27 @@ gth_image_dragger_class_init (GthImageDraggerClass *class)
 
 
 static void
-gth_image_dragger_instance_init (GthImageDragger *dragger)
+gth_image_dragger_init (GthImageDragger *dragger)
 {
 	dragger->priv = G_TYPE_INSTANCE_GET_PRIVATE (dragger, GTH_TYPE_IMAGE_DRAGGER, GthImageDraggerPrivate);
 }
 
 
 static void
-_gth_image_dragger_update_cursor (GthImageDragger *self)
+gth_image_dragger_set_viewer (GthImageViewerTool *base,
+			      GthImageViewer     *image_viewer)
 {
-	GdkCursor *cursor;
+	GthImageDragger *self = GTH_IMAGE_DRAGGER (base);
+	self->priv->viewer = image_viewer;
+}
 
-	if (self->priv->draggable)
-		cursor = gth_cursor_get (gtk_widget_get_window (GTK_WIDGET (self->priv->viewer)), GTH_CURSOR_HAND_OPEN);
-	else
-		cursor = gdk_cursor_new (GDK_LEFT_PTR);
-	gth_image_viewer_set_cursor (self->priv->viewer, cursor);
 
-	gdk_cursor_unref (cursor);
+static void
+gth_image_dragger_unset_viewer (GthImageViewerTool *base,
+		       	         GthImageViewer     *image_viewer)
+{
+	GthImageDragger *self = GTH_IMAGE_DRAGGER (base);
+	self->priv->viewer = NULL;
 }
 
 
@@ -95,6 +103,18 @@ gth_image_dragger_unrealize (GthImageViewerTool *base)
 }
 
 
+static void
+_gth_image_dragger_update_cursor (GthImageDragger *self)
+{
+	GdkCursor *cursor;
+
+	cursor = gdk_cursor_new (GDK_LEFT_PTR);
+	gth_image_viewer_set_cursor (self->priv->viewer, cursor);
+
+	g_object_unref (cursor);
+}
+
+
 static void
 gth_image_dragger_size_allocate (GthImageViewerTool *base,
 				 GtkAllocation      *allocation)
@@ -135,38 +155,30 @@ gth_image_dragger_unmap (GthImageViewerTool *base)
 
 
 static void
-gth_image_dragger_expose (GthImageViewerTool *self,
-			  GdkEventExpose     *event,
-		          cairo_t            *cr)
+gth_image_dragger_draw (GthImageViewerTool *self,
+		        cairo_t            *cr)
 {
 	GthImageDragger *dragger;
 	GthImageViewer  *viewer;
-	GdkInterpType    interp_type;
 
 	dragger = (GthImageDragger *) self;
 	viewer = dragger->priv->viewer;
 
-	if (gth_image_viewer_get_current_pixbuf (viewer) == NULL)
+	gth_image_viewer_paint_background (viewer, cr);
+
+	if (gth_image_viewer_get_current_image (viewer) == NULL)
 		return;
 
-	if (gth_image_viewer_get_zoom_quality (viewer) == GTH_ZOOM_QUALITY_LOW)
-		interp_type = GDK_INTERP_TILES;
-	else
-		interp_type = GDK_INTERP_BILINEAR;
-
-	if (gth_image_viewer_get_zoom (viewer) == 1.0)
-		interp_type = GDK_INTERP_NEAREST;
-
 	gth_image_viewer_paint_region (viewer,
 				       cr,
-				       gth_image_viewer_get_current_pixbuf (viewer),
+				       gth_image_viewer_get_current_image (viewer),
 				       viewer->x_offset - viewer->image_area.x,
 				       viewer->y_offset - viewer->image_area.y,
 				       &viewer->image_area,
-				       event->region,
-				       interp_type);
+				       NULL,
+				       gth_image_viewer_get_zoom_quality_filter (viewer));
 
-	gth_image_viewer_apply_painters (viewer, event, cr);
+	gth_image_viewer_apply_painters (viewer, cr);
 }
 
 
@@ -186,21 +198,24 @@ gth_image_dragger_button_press (GthImageViewerTool *self,
 		return FALSE;
 
 	if ((event->button == 1) && ! viewer->dragging) {
-		GdkCursor *cursor;
-		int        retval;
+		GdkCursor     *cursor;
+		GdkGrabStatus  retval;
 
-		cursor = gth_cursor_get (gtk_widget_get_window (widget), GTH_CURSOR_HAND_CLOSED);
-		retval = gdk_pointer_grab (gtk_widget_get_window (widget),
-					   FALSE,
-					   (GDK_POINTER_MOTION_MASK
-					    | GDK_POINTER_MOTION_HINT_MASK
-					    | GDK_BUTTON_RELEASE_MASK),
-					   NULL,
-					   cursor,
-					   event->time);
-		gdk_cursor_unref (cursor);
+		cursor = gdk_cursor_new_from_name (gtk_widget_get_display (widget), "grabbing");
+		retval = gdk_device_grab (event->device,
+					  gtk_widget_get_window (widget),
+					  GDK_OWNERSHIP_WINDOW,
+					  FALSE,
+					  (GDK_POINTER_MOTION_MASK
+					   | GDK_POINTER_MOTION_HINT_MASK
+					   | GDK_BUTTON_RELEASE_MASK),
+					  cursor,
+					  event->time);
 
-		if (retval != 0)
+		if (cursor != NULL)
+			g_object_unref (cursor);
+
+		if (retval != GDK_GRAB_SUCCESS)
 			return FALSE;
 
 		viewer->pressed = TRUE;
@@ -227,7 +242,7 @@ gth_image_dragger_button_release (GthImageViewerTool *self,
 	viewer = dragger->priv->viewer;
 
 	if (viewer->dragging)
-		gdk_pointer_ungrab (event->time);
+		gdk_device_ungrab (event->device, event->time);
 
 	return TRUE;
 }
@@ -252,8 +267,8 @@ gth_image_dragger_motion_notify (GthImageViewerTool *self,
 		return FALSE;
 
 	gth_image_viewer_scroll_to (viewer,
-				    viewer->x_offset + viewer->event_x_prev - event->x,
-				    viewer->y_offset + viewer->event_y_prev - event->y);
+				    viewer->drag_x_start - event->x,
+				    viewer->drag_y_start - event->y);
 
 	return TRUE;
 }
@@ -274,14 +289,16 @@ gth_image_dragger_zoom_changed (GthImageViewerTool *self)
 
 
 static void
-gth_image_dragger_gth_image_tool_interface_init (GthImageViewerToolIface *iface)
+gth_image_dragger_gth_image_tool_interface_init (GthImageViewerToolInterface *iface)
 {
+	iface->set_viewer = gth_image_dragger_set_viewer;
+	iface->unset_viewer = gth_image_dragger_unset_viewer;
 	iface->realize = gth_image_dragger_realize;
 	iface->unrealize = gth_image_dragger_unrealize;
 	iface->size_allocate = gth_image_dragger_size_allocate;
 	iface->map = gth_image_dragger_map;
 	iface->unmap = gth_image_dragger_unmap;
-	iface->expose = gth_image_dragger_expose;
+	iface->draw = gth_image_dragger_draw;
 	iface->button_press = gth_image_dragger_button_press;
 	iface->button_release = gth_image_dragger_button_release;
 	iface->motion_notify = gth_image_dragger_motion_notify;
@@ -290,47 +307,8 @@ gth_image_dragger_gth_image_tool_interface_init (GthImageViewerToolIface *iface)
 }
 
 
-GType
-gth_image_dragger_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthImageDraggerClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_image_dragger_class_init,
-			NULL,
-			NULL,
-			sizeof (GthImageDragger),
-			0,
-			(GInstanceInitFunc) gth_image_dragger_instance_init
-		};
-		static const GInterfaceInfo gth_image_tool_info = {
-			(GInterfaceInitFunc) gth_image_dragger_gth_image_tool_interface_init,
-			(GInterfaceFinalizeFunc) NULL,
-			NULL
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthImageDragger",
-					       &type_info,
-					       0);
-		g_type_add_interface_static (type, GTH_TYPE_IMAGE_VIEWER_TOOL, &gth_image_tool_info);
-	}
-
-	return type;
-}
-
-
 GthImageViewerTool *
-gth_image_dragger_new (GthImageViewer *viewer)
+gth_image_dragger_new (void)
 {
-	GthImageDragger *dragger;
-
-	dragger = g_object_new (GTH_TYPE_IMAGE_DRAGGER, NULL);
-	dragger->priv->viewer = viewer;
-
-	return GTH_IMAGE_VIEWER_TOOL (dragger);
+	return (GthImageViewerTool *) g_object_new (GTH_TYPE_IMAGE_DRAGGER, NULL);
 }
