@@ -43,11 +43,13 @@ enum {
 
 
 typedef struct {
+	int                 ref;
 	GthImagePreloader  *self;
 	GthFileData        *file_data;
 	int                 requested_size;
 	gboolean            loaded;
 	gboolean            error;
+	gboolean	    canceled;
 	GthImageLoader     *loader;
 	GthImage           *image;
 	int                 original_width;
@@ -81,10 +83,12 @@ struct _GthImagePreloaderPrivate {
 };
 
 
-static gpointer parent_class = NULL;
 static guint gth_image_preloader_signals[LAST_SIGNAL] = { 0 };
 
 
+G_DEFINE_TYPE (GthImagePreloader, gth_image_preloader, G_TYPE_OBJECT)
+
+
 /* -- Preloader -- */
 
 
@@ -94,10 +98,12 @@ preloader_new (GthImagePreloader *self)
 	Preloader *preloader;
 
 	preloader = g_new0 (Preloader, 1);
+	preloader->ref = 1;
 	preloader->self = self;
 	preloader->file_data = NULL;
 	preloader->loaded = FALSE;
 	preloader->error = FALSE;
+	preloader->canceled = FALSE;
 	preloader->loader = gth_image_loader_new (NULL, NULL);
 	gth_image_loader_set_preferred_format (preloader->loader, GTH_IMAGE_FORMAT_CAIRO_SURFACE);
 	preloader->image = NULL;
@@ -108,11 +114,21 @@ preloader_new (GthImagePreloader *self)
 }
 
 
+static Preloader *
+preloader_ref (Preloader *preloader)
+{
+	preloader->ref++;
+	return preloader;
+}
+
+
 static void
-preloader_free (Preloader *preloader)
+preloader_unref (Preloader *preloader)
 {
 	if (preloader == NULL)
 		return;
+	if (--preloader->ref > 0)
+		return;
 	_g_object_unref (preloader->image);
 	_g_object_unref (preloader->loader);
 	_g_object_unref (preloader->file_data);
@@ -219,14 +235,15 @@ gth_image_preloader_finalize (GObject *object)
 	}
 
 	for (i = 0; i < self->priv->n_preloaders; i++) {
-		preloader_free (self->priv->loader[i]);
+		self->priv->loader[i]->canceled = TRUE;
+		preloader_unref (self->priv->loader[i]);
 		self->priv->loader[i] = NULL;
 	}
 	g_free (self->priv->loader);
 	_g_object_unref (self->priv->requested_file);
 	g_object_unref (self->priv->cancellable);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (gth_image_preloader_parent_class)->finalize (object);
 }
 
 
@@ -235,7 +252,6 @@ gth_image_preloader_class_init (GthImagePreloaderClass *class)
 {
 	GObjectClass *object_class;
 
-	parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (GthImagePreloaderPrivate));
 
 	gth_image_preloader_signals[REQUESTED_READY] =
@@ -286,34 +302,6 @@ gth_image_preloader_init (GthImagePreloader *self)
 }
 
 
-GType
-gth_image_preloader_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo type_info = {
-			sizeof (GthImagePreloaderClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gth_image_preloader_class_init,
-			NULL,
-			NULL,
-			sizeof (GthImagePreloader),
-			0,
-			(GInstanceInitFunc) gth_image_preloader_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "GthImagePreloader",
-					       &type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 GthImagePreloader *
 gth_image_preloader_new (GthLoadPolicy load_policy,
 			 int           n_preloaders)
@@ -381,6 +369,7 @@ typedef struct {
 static void
 load_request_free (LoadRequest *load_request)
 {
+	preloader_unref (load_request->preloader);
 	g_object_unref (load_request->file_data);
 	g_free (load_request);
 }
@@ -401,6 +390,11 @@ image_loader_ready_cb (GObject      *source_object,
 	gboolean            success;
 	int                 interval;
 
+	if (preloader->canceled) {
+		load_request_free (load_request);
+		return;
+	}
+
 	self->priv->current = -1;
 
 	success = gth_image_loader_load_finish  (GTH_IMAGE_LOADER (source_object),
@@ -528,7 +522,7 @@ start_next_loader (GthImagePreloader *self)
 		preloader->image = NULL;
 
 		load_request = g_new0 (LoadRequest, 1);
-		load_request->preloader = preloader;
+		load_request->preloader = preloader_ref (preloader);
 		load_request->file_data = g_object_ref (preloader->file_data);
 		load_request->requested_size = preloader->requested_size;
 
