@@ -29,7 +29,7 @@
 #define CHECK_THREAD_RATE 5
 
 
-static gpointer gth_metadata_provider_parent_class = NULL;
+G_DEFINE_TYPE (GthMetadataProvider, gth_metadata_provider, G_TYPE_OBJECT)
 
 
 static gboolean
@@ -74,8 +74,6 @@ gth_metadata_provider_real_write (GthMetadataProvider   *self,
 static void
 gth_metadata_provider_class_init (GthMetadataProviderClass * klass)
 {
-	gth_metadata_provider_parent_class = g_type_class_peek_parent (klass);
-
 	GTH_METADATA_PROVIDER_CLASS (klass)->can_read = gth_metadata_provider_real_can_read;
 	GTH_METADATA_PROVIDER_CLASS (klass)->can_write = gth_metadata_provider_real_can_write;
 	GTH_METADATA_PROVIDER_CLASS (klass)->read = gth_metadata_provider_real_read;
@@ -83,26 +81,10 @@ gth_metadata_provider_class_init (GthMetadataProviderClass * klass)
 }
 
 
-GType
-gth_metadata_provider_get_type (void)
+static void
+gth_metadata_provider_init (GthMetadataProvider *self)
 {
-	static GType gth_metadata_provider_type_id = 0;
-	if (gth_metadata_provider_type_id == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthMetadataProviderClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_metadata_provider_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthMetadataProvider),
-			0,
-			(GInstanceInitFunc) NULL,
-			NULL
-		};
-		gth_metadata_provider_type_id = g_type_register_static (G_TYPE_OBJECT, "GthMetadataProvider", &g_define_type_info, 0);
-	}
-	return gth_metadata_provider_type_id;
+	/* void */
 }
 
 
@@ -177,6 +159,8 @@ _g_query_metadata_async_thread (GSimpleAsyncResult *result,
 	GList              *scan;
 	GError             *error = NULL;
 
+	performance (DEBUG_INFO, "_g_query_metadata_async_thread start");
+
 	qmd = g_simple_async_result_get_op_res_gpointer (result);
 
 	providers = NULL;
@@ -203,17 +187,17 @@ _g_query_metadata_async_thread (GSimpleAsyncResult *result,
 
 	_g_object_list_unref (providers);
 
-	if (error == NULL) {
-		for (scan = qmd->files; scan; scan = scan->next) {
-			GthFileData *file_data = scan->data;
-			gth_hook_invoke ("read-metadata-ready", file_data, qmd->attributes);
-		}
-	}
+	performance (DEBUG_INFO, "_g_query_metadata_async_thread before read-metadata-ready");
+
+	if (error == NULL)
+		gth_hook_invoke ("read-metadata-ready", qmd->files, qmd->attributes);
 
 	if (error != NULL) {
 		g_simple_async_result_set_from_error (result, error);
 		g_error_free (error);
 	}
+
+	performance (DEBUG_INFO, "_g_query_metadata_async_thread end");
 }
 
 
