@@ -33,9 +33,6 @@
 #define PREVIEW_SIZE 256
 
 
-static gpointer gth_overwrite_dialog_parent_class = NULL;
-
-
 struct _GthOverwriteDialogPrivate {
 	GtkBuilder     *builder;
 	GFile          *source;
@@ -50,6 +47,9 @@ struct _GthOverwriteDialogPrivate {
 };
 
 
+G_DEFINE_TYPE (GthOverwriteDialog, gth_overwrite_dialog, GTK_TYPE_DIALOG)
+
+
 static void
 gth_overwrite_dialog_finalize (GObject *object)
 {
@@ -73,9 +73,7 @@ gth_overwrite_dialog_finalize (GObject *object)
 static void
 gth_overwrite_dialog_class_init (GthOverwriteDialogClass *klass)
 {
-	gth_overwrite_dialog_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (GthOverwriteDialogPrivate));
-
 	G_OBJECT_CLASS (klass)->finalize = gth_overwrite_dialog_finalize;
 }
 
@@ -89,34 +87,6 @@ gth_overwrite_dialog_init (GthOverwriteDialog *self)
 }
 
 
-GType
-gth_overwrite_dialog_get_type (void)
-{
-	static GType type = 0;
-
-	if (type == 0) {
-		static const GTypeInfo g_define_type_info = {
-			sizeof (GthOverwriteDialogClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) gth_overwrite_dialog_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (GthOverwriteDialog),
-			0,
-			(GInstanceInitFunc) gth_overwrite_dialog_init,
-			NULL
-		};
-		type = g_type_register_static (GTK_TYPE_DIALOG,
-					       "GthOverwriteDialog",
-					       &g_define_type_info,
-					       0);
-	}
-
-	return type;
-}
-
-
 static void
 image_loader_ready_cb (GObject      *source_object,
                        GAsyncResult *result,
@@ -174,7 +144,7 @@ info_ready_cb (GList    *files,
 
 		gtk_label_set_text (GTK_LABEL (_gtk_builder_get_widget (self->priv->builder, "new_image_filename_label")), g_file_info_get_display_name (self->priv->source_data->info));
 
-		text = g_format_size_for_display (g_file_info_get_size (self->priv->source_data->info));
+		text = g_format_size (g_file_info_get_size (self->priv->source_data->info));
 		gtk_label_set_text (GTK_LABEL (_gtk_builder_get_widget (self->priv->builder, "new_image_size_label")), text);
 		g_free (text);
 
@@ -220,7 +190,7 @@ info_ready_cb (GList    *files,
 
 	gtk_label_set_text (GTK_LABEL (_gtk_builder_get_widget (self->priv->builder, "old_image_filename_label")), g_file_info_get_display_name (self->priv->destination_data->info));
 
-	text = g_format_size_for_display (g_file_info_get_size (self->priv->destination_data->info));
+	text = g_format_size (g_file_info_get_size (self->priv->destination_data->info));
 	gtk_label_set_text (GTK_LABEL (_gtk_builder_get_widget (self->priv->builder, "old_image_size_label")), text);
 	g_free (text);
 
