@@ -23,15 +23,17 @@
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
 #include <gtk/gtk.h>
-#ifdef HAVE_UNIQUE
-#include <unique/unique.h>
+#ifdef HAVE_GSTREAMER
+#  include <gst/gst.h>
 #endif
 #ifdef HAVE_CLUTTER
-#include <clutter/clutter.h>
-#include <clutter-gtk/clutter-gtk.h>
+#  include <clutter/clutter.h>
+#  include <clutter-gtk/clutter-gtk.h>
 #endif
-#include "eggsmclient.h"
-#include "gconf-utils.h"
+#ifdef USE_SMCLIENT
+#  include "eggsmclient.h"
+#endif
+#include "eggdesktopfile.h"
 #include "glib-utils.h"
 #include "gth-browser.h"
 #include "gth-file-data.h"
@@ -41,26 +43,11 @@
 #include "main-migrate.h"
 
 
-enum {
-	COMMAND_UNUSED,
-	COMMAND_FULLSCREEN,
-	COMMAND_IMPORT_PHOTOS,
-	COMMAND_SLIDESHOW
-};
-
-
-gboolean NewWindow = FALSE;
-gboolean StartInFullscreen = FALSE;
-gboolean StartSlideshow = FALSE;
-gboolean ImportPhotos = FALSE;
-#ifdef HAVE_CLUTTER
-int      ClutterInitResult = CLUTTER_INIT_ERROR_UNKNOWN;
-#endif
-
-
-#ifdef HAVE_UNIQUE
-static UniqueApp   *gthumb_app;
-#endif
+GtkApplication     *Main_Application = NULL;
+gboolean            NewWindow = FALSE;
+gboolean            StartInFullscreen = FALSE;
+gboolean            StartSlideshow = FALSE;
+gboolean            ImportPhotos = FALSE;
 static char       **remaining_args;
 static const char  *program_argv0; /* argv[0] from main(); used as the command to restart the program */
 static gboolean     Restart = FALSE;
@@ -95,6 +82,53 @@ static const GOptionEntry options[] = {
 };
 
 
+static void
+open_browser_window (GFile    *location,
+		     GFile    *file_to_select,
+		     gboolean  force_new_window)
+{
+	gboolean   reuse_active_window;
+	GtkWidget *window;
+
+	if (! force_new_window) {
+		GSettings *settings;
+
+		settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
+		reuse_active_window = g_settings_get_boolean (settings, PREF_BROWSER_REUSE_ACTIVE_WINDOW);
+		g_object_unref (settings);
+	}
+	else
+		reuse_active_window = FALSE;
+
+	window = NULL;
+
+	if (reuse_active_window) {
+		GList *windows = gtk_application_get_windows (Main_Application);
+		if (windows != NULL)
+			window = windows->data;
+	}
+
+	if (window == NULL)
+		window = gth_browser_new (location, file_to_select);
+	else if (file_to_select != NULL)
+		gth_browser_go_to (GTH_BROWSER (window), location, file_to_select);
+	else
+		gth_browser_load_location (GTH_BROWSER (window), location);
+
+	if (! StartSlideshow)
+		gtk_window_present (GTK_WINDOW (window));
+}
+
+
+static void
+import_photos_from_location (GFile *location)
+{
+	GtkWidget *window;
+
+	window = gth_browser_new (NULL, NULL);
+	gth_hook_invoke ("import-photos", window, location, NULL);
+}
+
 
 static void
 migrate_data (void)
@@ -103,10 +137,16 @@ migrate_data (void)
 }
 
 
+/* -- session management -- */
+
+
+#ifdef USE_SMCLIENT
+
+
 static void
-gth_save_state (EggSMClient *client,
-		GKeyFile    *state,
-		gpointer     user_data)
+client_save_state (EggSMClient *client,
+		   GKeyFile    *state,
+		   gpointer     user_data)
 {
 	const char *argv[2] = { NULL };
 	GList      *scan;
@@ -117,7 +157,7 @@ gth_save_state (EggSMClient *client,
 	egg_sm_client_set_restart_command (client, 1, argv);
 
 	i = 0;
-	for (scan = gth_window_get_window_list (); scan; scan = scan->next) {
+	for (scan = gtk_application_get_windows (Main_Application); scan; scan = scan->next) {
 		GtkWidget   *window = scan->data;
 		GFile       *location;
 		char        *key;
@@ -196,7 +236,7 @@ static void
 client_quit_requested_cb (EggSMClient *client,
 			  gpointer     data)
 {
-	client_window = gth_window_get_window_list ();
+	client_window = gtk_application_get_windows (Main_Application);
 	check_whether_to_save (client);
 }
 
@@ -210,28 +250,7 @@ client_quit_cb (EggSMClient *client,
 
 
 static void
-gth_session_manager_init (void)
-{
-	EggSMClient *client = NULL;
-
-	client = egg_sm_client_get ();
-	g_signal_connect (client,
-			  "save_state",
-			  G_CALLBACK (gth_save_state),
-			  NULL);
-	g_signal_connect (client,
-			  "quit_requested",
-			  G_CALLBACK (client_quit_requested_cb),
-			  NULL);
-	g_signal_connect (client,
-			  "quit",
-			  G_CALLBACK (client_quit_cb),
-			  NULL);
-}
-
-
-static void
-gth_restore_session (EggSMClient *client)
+restore_session (EggSMClient *client)
 {
 	GKeyFile *state = NULL;
 	guint     i;
@@ -252,11 +271,9 @@ gth_restore_session (EggSMClient *client)
 
 		g_assert (location != NULL);
 
-		window = gth_browser_new (NULL);
-		gtk_widget_show (window);
-
 		file = g_file_new_for_uri (location);
-		gth_browser_load_location(GTH_BROWSER (window), file);
+		window = gth_browser_new (file, NULL);
+		gtk_widget_show (window);
 
 		g_object_unref (file);
 		g_free (location);
@@ -264,169 +281,49 @@ gth_restore_session (EggSMClient *client)
 }
 
 
-#ifdef HAVE_UNIQUE
-
-
-static void
-show_window (GtkWindow  *window,
-	     const char *startup_id,
-	     GdkScreen  *screen)
-{
-	gtk_window_set_startup_id (window, startup_id);
-	gtk_window_set_screen (window, screen);
-	gtk_window_present (window);
-}
-
-
-static UniqueResponse
-unique_app_message_received_cb (UniqueApp         *unique_app,
-				UniqueCommand      command,
-				UniqueMessageData *message,
-				guint              time_,
-				gpointer           user_data)
-{
-	UniqueResponse  res;
-	char           *uri;
-	GFile          *location = NULL;
-	GtkWidget      *window = NULL;
-
-	res = UNIQUE_RESPONSE_OK;
-
-	switch (command) {
-	case UNIQUE_OPEN:
-	case UNIQUE_NEW:
-		if (command == UNIQUE_OPEN)
-			window = gth_window_get_current_window ();
-
-		if (window == NULL)
-			window = gth_browser_new (NULL);
-
-		show_window (GTK_WINDOW (window),
-			     unique_message_data_get_startup_id (message),
-			     unique_message_data_get_screen (message));
-
-		uri = unique_message_data_get_text (message);
-		location = g_file_new_for_uri (uri);
-		gth_browser_load_location (GTH_BROWSER (window), location);
-
-		g_object_unref (location);
-		g_free (uri);
-		break;
-
-	case COMMAND_IMPORT_PHOTOS:
-		window = gth_window_get_current_window ();
-		if (window == NULL)
-			window = gth_browser_new (NULL);
-
-		uri = unique_message_data_get_text (message);
-		if ((uri != NULL) && (strcmp (uri, "") != 0))
-			location = g_file_new_for_uri (uri);
-		gth_hook_invoke ("import-photos", window, location, NULL);
-
-		_g_object_unref (location);
-		g_free (uri);
-		break;
-
-	case COMMAND_SLIDESHOW:
-		window = gth_window_get_current_window ();
-		if (window == NULL)
-			window = gth_browser_new (NULL);
-		gth_hook_invoke ("slideshow", window, NULL);
-
-	default:
-		res = UNIQUE_RESPONSE_PASSTHROUGH;
-		break;
-	}
-
-	return res;
-}
-
-
 #endif
 
 
+/* -- main application -- */
+
+
+typedef GtkApplication      GthApplication;
+typedef GtkApplicationClass GthApplicationClass;
+
+static gpointer gth_application_parent_class;
+
+
+G_DEFINE_TYPE (GthApplication, gth_application, GTK_TYPE_APPLICATION)
+
+
 static void
-open_browser_window (GFile *location,
-		     GFile *current_file)
+gth_application_finalize (GObject *object)
 {
-#ifdef HAVE_UNIQUE
-	if (unique_app_is_running (gthumb_app)) {
-		UniqueMessageData *data;
-		char              *uri;
-
-		data = unique_message_data_new ();
-		uri = g_file_get_uri (location);
-		unique_message_data_set_text (data, uri, -1);
-		unique_app_send_message (gthumb_app, NewWindow ? UNIQUE_NEW : UNIQUE_OPEN, data);
-
-		g_free (uri);
-		unique_message_data_free (data);
-	}
-	else
-
-#endif
-
-	{
-		GtkWidget *window;
-
-		window = gth_browser_new (NULL);
-		if (! StartSlideshow)
-			gtk_window_present (GTK_WINDOW (window));
-		if (current_file != NULL)
-			gth_browser_go_to (GTH_BROWSER (window), location, current_file);
-		else
-			gth_browser_load_location (GTH_BROWSER (window), location);
-	}
+        G_OBJECT_CLASS (gth_application_parent_class)->finalize (object);
 }
 
 
 static void
-import_photos_from_location (GFile *location)
+gth_application_init (GthApplication *app)
 {
-#ifdef HAVE_UNIQUE
-	if (unique_app_is_running (gthumb_app)) {
-		UniqueMessageData *data;
-
-		data = unique_message_data_new ();
-		if (location != NULL) {
-			char *uri;
-			uri = g_file_get_uri (location);
-			unique_message_data_set_text (data, uri, -1);
-			g_free (uri);
-		}
-		unique_app_send_message (gthumb_app, COMMAND_IMPORT_PHOTOS, data);
-		unique_message_data_free (data);
-	}
-	else
-
+#ifdef GDK_WINDOWING_X11
+	egg_set_desktop_file (GTHUMB_APPLICATIONS_DIR "/gthumb.desktop");
+#else
+	/* manually set name and icon */
+	g_set_application_name (_("gThumb"));
+	gtk_window_set_default_icon_name ("gthumb");
 #endif
-
-	{
-		GtkWidget *window;
-
-		window = gth_browser_new (NULL);
-		gth_hook_invoke ("import-photos", window, location, NULL);
-	}
 }
 
 
 static void
-prepare_application (void)
+gth_application_startup (GApplication *application)
 {
-	EggSMClient *client = NULL;
-	const char  *arg;
-	int          i;
-	GList       *files;
-	GList       *dirs;
-	GFile       *location;
-	GList       *scan;
-
-#ifdef HAVE_UNIQUE
-	gthumb_app = unique_app_new_with_commands ("org.gnome.gthumb", NULL,
-						   "import-photos", COMMAND_IMPORT_PHOTOS,
-						   NULL);
-#endif
+	G_APPLICATION_CLASS (gth_application_parent_class)->startup (application);
 
+	gth_pref_initialize ();
+	migrate_data ();
+	gth_main_initialize ();
 	gth_main_register_default_hooks ();
 	gth_main_register_file_source (GTH_TYPE_FILE_SOURCE_VFS);
 	gth_main_register_default_sort_types ();
@@ -435,20 +332,96 @@ prepare_application (void)
 	gth_main_register_default_metadata ();
 	gth_main_activate_extensions ();
 	gth_hook_invoke ("initialize", NULL);
+}
 
-#ifdef HAVE_UNIQUE
-	if (! unique_app_is_running (gthumb_app))
-		g_signal_connect (gthumb_app,
-				  "message-received",
-				  G_CALLBACK (unique_app_message_received_cb),
+
+static GOptionContext *
+gth_application_create_option_context (void)
+{
+	GOptionContext *context;
+	static gsize    initialized = FALSE;
+
+	context = g_option_context_new (N_("- Image browser and viewer"));
+	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+	g_option_context_set_ignore_unknown_options (context, TRUE);
+	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+
+	if (g_once_init_enter (&initialized)) {
+		g_option_context_add_group (context, gtk_get_option_group (TRUE));
+#ifdef USE_SMCLIENT
+		g_option_context_add_group (context, egg_sm_client_get_option_group ());
+#endif
+#ifdef HAVE_CLUTTER
+		g_option_context_add_group (context, cogl_get_option_group ());
+		g_option_context_add_group (context, clutter_get_option_group_without_init ());
+		g_option_context_add_group (context, gtk_clutter_get_option_group ());
+#endif
+#ifdef HAVE_GSTREAMER
+		g_option_context_add_group (context, gst_init_get_option_group ());
+#endif
+		g_once_init_leave (&initialized, TRUE);
+	}
+
+	return context;
+}
+
+
+static int
+gth_application_command_line (GApplication            *application,
+                              GApplicationCommandLine *command_line)
+{
+	char           **argv;
+	int              argc;
+	GOptionContext  *context;
+	GError          *error = NULL;
+	const char      *arg;
+	int              i;
+	GList           *files;
+	GList           *dirs;
+	GFile           *location;
+	gboolean         singleton;
+	GList           *scan;
+
+	argv = g_application_command_line_get_arguments (command_line, &argc);
+
+	/* parse command line options */
+
+	context = gth_application_create_option_context ();
+	if (! g_option_context_parse (context, &argc, &argv, &error)) {
+		g_critical ("Failed to parse arguments: %s", error->message);
+		g_error_free (error);
+		g_option_context_free (context);
+		return EXIT_FAILURE;
+	}
+	g_option_context_free (context);
+
+	/* restore the session */
+
+#ifdef USE_SMCLIENT
+	{
+		EggSMClient *client;
+
+		client = egg_sm_client_get ();
+		g_signal_connect (client,
+				  "save_state",
+				  G_CALLBACK (client_save_state),
 				  NULL);
+		g_signal_connect (client,
+				  "quit_requested",
+				  G_CALLBACK (client_quit_requested_cb),
+				  NULL);
+		g_signal_connect (client,
+				  "quit",
+				  G_CALLBACK (client_quit_cb),
+				  NULL);
+		if (egg_sm_client_is_resumed (client)) {
+			restore_session (client);
+			return 0;
+		}
+	}
 #endif
 
-	client = egg_sm_client_get ();
-	if (egg_sm_client_is_resumed (client)) {
-		gth_restore_session (client);
-		return;
-	}
+	/* exec the command line */
 
 	if (ImportPhotos) {
 		GFile *location = NULL;
@@ -456,28 +429,34 @@ prepare_application (void)
 		if (remaining_args != NULL)
 			location = g_file_new_for_commandline_arg (remaining_args[0]);
 		import_photos_from_location (location);
+		gdk_notify_startup_complete ();
 
-		return;
+		return 0;
 	}
 
 	if (remaining_args == NULL) { /* No location specified. */
-		GFile *location;
-		char  *current_file_uri;
-		GFile *current_file;
+		GFile     *location;
+		GSettings *settings;
+		char      *file_to_select_uri;
+		GFile     *file_to_select;
 
 		location = g_file_new_for_uri (gth_pref_get_startup_location ());
-		current_file_uri = eel_gconf_get_path (PREF_STARTUP_CURRENT_FILE, NULL);
-		if (current_file_uri != NULL)
-			current_file = g_file_new_for_uri (current_file_uri);
+		settings = g_settings_new (GTHUMB_BROWSER_SCHEMA);
+		file_to_select_uri = _g_settings_get_uri (settings, PREF_BROWSER_STARTUP_CURRENT_FILE);
+		if (file_to_select_uri != NULL)
+			file_to_select = g_file_new_for_uri (file_to_select_uri);
 		else
-			current_file = NULL;
-		open_browser_window (location, current_file);
+			file_to_select = NULL;
 
-		_g_object_unref (current_file);
-		g_free (current_file_uri);
+		open_browser_window (location, file_to_select, TRUE);
+		gdk_notify_startup_complete ();
+
+		_g_object_unref (file_to_select);
+		g_free (file_to_select_uri);
+		g_object_unref (settings);
 		g_object_unref (location);
 
-		return;
+		return 0;
 	}
 
 	/* At least a location was specified */
@@ -500,92 +479,128 @@ prepare_application (void)
 
 	location = gth_hook_invoke_get ("command-line-files", files);
 	if (location != NULL) {
-		open_browser_window (location, NULL);
+		open_browser_window (location, NULL, FALSE);
 		g_object_unref (location);
 	}
-	else /* Open each file in a new window */
+	else {
+		/* Open each file in a new window */
+
+		singleton = (files != NULL) && (files->next == NULL);
 		for (scan = files; scan; scan = scan->next)
-			open_browser_window ((GFile *) scan->data, NULL);
+			open_browser_window ((GFile *) scan->data, NULL, ! singleton);
+	}
 
 	/* Open each dir in a new window */
 
+	singleton = (dirs != NULL) && (dirs->next == NULL);
 	for (scan = dirs; scan; scan = scan->next)
-		open_browser_window ((GFile *) scan->data, NULL);
+		open_browser_window ((GFile *) scan->data, NULL, ! singleton);
+
+	gdk_notify_startup_complete ();
 
 	_g_object_list_unref (dirs);
 	_g_object_list_unref (files);
+
+	return 0;
 }
 
 
+static gboolean
+gth_application_local_command_line (GApplication   *application,
+                                    char         ***arguments,
+                                    int            *exit_status)
+{
+        char           **local_argv;
+        int              local_argc;
+        GOptionContext  *context;
+        GError          *error = NULL;
+        gboolean         handled_locally = FALSE;
+
+        local_argv = g_strdupv (*arguments);
+        local_argc = g_strv_length (local_argv);
+
+        *exit_status = 0;
+
+        context = gth_application_create_option_context ();
+	if (! g_option_context_parse (context, &local_argc, &local_argv, &error)) {
+		*exit_status = EXIT_FAILURE;
+		g_critical ("Failed to parse arguments: %s", error->message);
+                g_clear_error (&error);
+                handled_locally = TRUE;
+	}
+
+	if (version) {
+		g_printf ("%s %s, Copyright © 2001-2010 Free Software Foundation, Inc.\n", PACKAGE_NAME, PACKAGE_VERSION);
+		handled_locally = TRUE;
+	}
+
+	g_option_context_free (context);
+        g_strfreev (local_argv);
+
+        return handled_locally;
+}
+
+
+static void
+gth_application_class_init (GthApplicationClass *klass)
+{
+	GObjectClass      *object_class;
+	GApplicationClass *application_class;
+
+	object_class = G_OBJECT_CLASS (klass);
+	object_class->finalize = gth_application_finalize;
+
+	application_class = G_APPLICATION_CLASS (klass);
+	application_class->startup = gth_application_startup;
+	application_class->command_line = gth_application_command_line;
+	application_class->local_command_line = gth_application_local_command_line;
+}
+
+
+static GtkApplication *
+gth_application_new (void)
+{
+        return g_object_new (gth_application_get_type (),
+                             "application-id", "org.gnome.Gthumb",
+                             "flags", 0,
+                             NULL);
+}
+
+
+/* -- main -- */
+
+
 int
 main (int argc, char *argv[])
 {
-	GOptionContext *context;
-	GError         *error = NULL;
-
-	if (! g_thread_supported ())
-		g_thread_init (NULL);
+	int status;
 
 	program_argv0 = argv[0];
 
+	g_thread_init (NULL);
+	g_type_init ();
+
 	/* text domain */
 
-	bindtextdomain (GETTEXT_PACKAGE, GTHUMB_LOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	/* command line options */
+	/* run the main application */
 
-	context = g_option_context_new (N_("- Image browser and viewer"));
-	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
-	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-	g_option_context_add_group (context, gtk_get_option_group (TRUE));
-	g_option_context_add_group (context, egg_sm_client_get_option_group ());
-#ifdef HAVE_CLUTTER
-	g_option_context_add_group (context, cogl_get_option_group ());
-	g_option_context_add_group (context, clutter_get_option_group_without_init ());
-#endif
-	if (! g_option_context_parse (context, &argc, &argv, &error)) {
-		g_critical ("Failed to parse arguments: %s", error->message);
-		g_error_free (error);
-		g_option_context_free (context);
-		return EXIT_FAILURE;
-	}
-
-	if (version) {
-		g_printf ("%s %s, Copyright © 2001-2010 Free Software Foundation, Inc.\n", PACKAGE_NAME, PACKAGE_VERSION);
-		return 0;
-	}
-
-#ifdef HAVE_CLUTTER
-	ClutterInitResult = gtk_clutter_init (NULL, NULL);
-#endif
-
-	/* other initializations */
-
-	gth_session_manager_init ();
-	gth_pref_initialize ();
-	migrate_data ();
-	gth_main_initialize ();
-	prepare_application ();
-
-	g_option_context_free (context);
-
-#ifdef HAVE_UNIQUE
-	if (! unique_app_is_running (gthumb_app))
-		gtk_main ();
-	g_object_unref (gthumb_app);
-#else
-	gtk_main ();
-#endif
+	Main_Application = gth_application_new ();
+	status = g_application_run (G_APPLICATION (Main_Application), argc, argv);
 
 	gth_main_release ();
 	gth_pref_release ();
+	g_object_unref (Main_Application);
+
+	/* restart if requested by the user */
 
 	if (Restart)
 		g_spawn_command_line_async (program_argv0, NULL);
 
-	return 0;
+	return status;
 }
 
 
@@ -595,7 +610,7 @@ gth_quit (gboolean restart)
 	GList *windows;
 	GList *scan;
 
-	windows = g_list_copy (gth_window_get_window_list ());
+	windows = g_list_copy (gtk_application_get_windows (Main_Application));
 	for (scan = windows; scan; scan = scan->next)
 		gth_window_close (GTH_WINDOW (scan->data));
 	g_list_free (windows);
